<?php
/**
 * @var \Psr\Container\ContainerInterface $container
 */

if (!defined('WPINC')) {
    define('WPINC', 'wp-includes');
}

$_SERVER['SERVER_PROTOCOL'] = 'HTTP/1.1';

require_once ABSPATH . WPINC . '/load.php';
require_once ABSPATH . WPINC . '/default-constants.php';
require_once ABSPATH . WPINC . '/plugin.php';

/*
 * These can't be directly globalized in version.php. When updating,
 * we're including version.php from another installation and don't want
 * these values to be overridden if already set.
 */
global $wp_version, $wp_db_version, $tinymce_version, $required_php_version, $required_mysql_version, $wp_local_package;
require_once ABSPATH . WPINC . '/version.php';

// Set initial default constants including WP_MEMORY_LIMIT, WP_MAX_MEMORY_LIMIT, WP_DEBUG, SCRIPT_DEBUG, WP_CONTENT_DIR and WP_CACHE.
if (!defined('KB_IN_BYTES')) {
    wp_initial_constants();
}

// WordPress calculates offsets from UTC.
date_default_timezone_set( 'UTC' );

// Turn register_globals off.
wp_unregister_GLOBALS();

// Standardize $_SERVER variables across setups.
wp_fix_server_vars();

// Check if we have received a request due to missing favicon.ico
wp_favicon_request();

// Check if we're in maintenance mode.
wp_maintenance();

// Start loading timer.
timer_start();

// Check if we're in WP_DEBUG mode.
wp_debug_mode();

// Define WP_LANG_DIR if not set.
wp_set_lang_dir();

require_once ABSPATH . WPINC . '/functions.php';

// Include the wpdb class and, if present, a db.php database drop-in.
global $wpdb;
require_wp_db();

// Set the database table prefix and the format specifiers for database table columns.
wp_set_wpdb_vars();

// Start the WordPress object cache, or an external object cache if the drop-in is present.
wp_start_object_cache();

// Attach the default filters.
require_once __DIR__ . '/wp-includes/default-filters.php';

require_once ABSPATH . WPINC . '/l10n.php';

require_once ABSPATH . WPINC . '/shortcodes.php';

require_once ABSPATH . WPINC . '/admin-bar.php';
require_once ABSPATH . WPINC . '/author-template.php';
require_once ABSPATH . WPINC . '/canonical.php';
require_once ABSPATH . WPINC . '/capabilities.php';
require_once ABSPATH . WPINC . '/category.php';
require_once ABSPATH . WPINC . '/category-template.php';
require_once ABSPATH . WPINC . '/comment.php';
require_once ABSPATH . WPINC . '/comment-template.php';
require_once ABSPATH . WPINC . '/cron.php';
require_once ABSPATH . WPINC . '/embed.php';
require_once ABSPATH . WPINC . '/feed.php';
require_once ABSPATH . WPINC . '/formatting.php';
require_once ABSPATH . WPINC . '/general-template.php';
require_once ABSPATH . WPINC . '/http.php';
require_once ABSPATH . WPINC . '/kses.php';
require_once ABSPATH . WPINC . '/link-template.php';
require_once ABSPATH . WPINC . '/media.php';
require_once ABSPATH . WPINC . '/meta.php';
require_once ABSPATH . WPINC . '/nav-menu.php';
require_once ABSPATH . WPINC . '/post.php';
require_once ABSPATH . WPINC . '/post-formats.php';
require_once ABSPATH . WPINC . '/post-template.php';
require_once ABSPATH . WPINC . '/post-thumbnail-template.php';
require_once ABSPATH . WPINC . '/query.php';
require_once ABSPATH . WPINC . '/revision.php';
require_once ABSPATH . WPINC . '/rewrite.php';
require_once ABSPATH . WPINC . '/script-loader.php';
require_once ABSPATH . WPINC . '/taxonomy.php';
require_once __DIR__ . '/wp-includes/template.php';
require_once ABSPATH . WPINC . '/theme.php';
require_once ABSPATH . WPINC . '/user.php';
require_once ABSPATH . WPINC . '/widgets.php';

require_once ABSPATH . WPINC . '/rest-api.php';

$GLOBALS['wp_embed'] = new WP_Embed();

// Define constants that rely on the API to obtain the default value.
// Define must-use plugin directory constants, which may be overridden in the sunrise.php drop-in.
wp_plugin_directory_constants();

$GLOBALS['wp_plugin_paths'] = [];

// Define constants after multisite is loaded.
wp_cookie_constants();

// Create common globals.
require_once ABSPATH . WPINC . '/vars.php';

// Make taxonomies and posts available to plugins and themes.
// @plugin authors: warning: these get registered again on the init hook.
create_initial_taxonomies();
create_initial_post_types();

// Load pluggable functions.
require_once ABSPATH . WPINC . '/pluggable.php';

/**
 * Holds the WordPress Rewrite object for creating pretty URLs
 * @global WP_Rewrite $wp_rewrite
 * @since 1.5.0
 */
$GLOBALS['wp_rewrite'] = new WP_Rewrite();

/**
 * WordPress Object
 * @global WP $wp
 * @since 2.0.0
 */
$GLOBALS['wp'] = new WP();

/**
 * WordPress Widget Factory Object
 * @global WP_Widget_Factory $wp_widget_factory
 * @since 2.8.0
 */
$GLOBALS['wp_widget_factory'] = new WP_Widget_Factory();

if (!defined('WP_TEST_NO_PLUGINS')) {
    require_once ABSPATH . 'wp-admin/includes/plugin.php';

    foreach ($this->wpPlugins ?? [] as $plugin) {
        if (!is_plugin_active($plugin)) {
            activate_plugin($plugin);
        }
    }

    // Load active plugins.
    foreach (wp_get_active_and_valid_plugins() as $plugin) {
        wp_register_plugin_realpath($plugin);
        /** @noinspection PhpIncludeInspection */
        include_once $plugin;
    }
    unset($plugin);
}

if (isset($container)) {
    /** @var \Ak\Wp\Plugin\PluginLoader $pluginLoader */
    $pluginLoader = $container->get(\Ak\Wp\Plugin\PluginLoader::class);
    $pluginLoader->register();
}

/**
 * Fires once activated plugins have loaded.
 *
 * Pluggable functions are also available at this point in the loading order.
 *
 * @since 1.5.0
 */
do_action('plugins_loaded');

// Define constants which affect functionality if not already defined.
wp_functionality_constants();

/**
 * WordPress Query object
 * @global WP_Query $wp_the_query
 * @since 2.0.0
 */
$GLOBALS['wp_the_query'] = new WP_Query();

/**
 * Holds the reference to @see $wp_the_query
 * Use this global for WordPress queries
 * @global WP_Query $wp_query
 * @since 1.5.0
 */
$GLOBALS['wp_query'] = $GLOBALS['wp_the_query'];

/**
 * Fires before the theme is loaded.
 *
 * @since 2.6.0
 */
do_action('setup_theme');

if (!defined('TEMPLATEPATH')) {
    // Define the template related constants.
    wp_templating_constants();
}

// Load the default text localization domain.
load_default_textdomain();

$locale = get_locale();
$locale_file = WP_LANG_DIR . "/$locale.php";
if ( ( 0 === validate_file( $locale ) ) && is_readable( $locale_file ) )
    /** @noinspection PhpIncludeInspection */
    require( $locale_file );
unset( $locale_file );

/**
 * WordPress Locale object for loading locale domain date and various strings.
 * @global WP_Locale $wp_locale
 * @since 2.1.0
 */
$GLOBALS['wp_locale'] = new WP_Locale();

/**
 *  WordPress Locale Switcher object for switching locales.
 *
 * @since 4.7.0
 *
 * @global WP_Locale_Switcher $wp_locale_switcher WordPress locale switcher object.
 */
$GLOBALS['wp_locale_switcher'] = new WP_Locale_Switcher();
$GLOBALS['wp_locale_switcher']->init();

// Load the functions for the active theme, for both parent and child theme if applicable.
if (! wp_installing() || 'wp-activate.php' === $pagenow) {
    if (TEMPLATEPATH !== STYLESHEETPATH && file_exists(STYLESHEETPATH . '/functions.php')) {
        /** @noinspection PhpIncludeInspection */
        include_once STYLESHEETPATH . '/functions.php';
    }

    if (file_exists(TEMPLATEPATH . '/functions.php')) {
        /** @noinspection PhpIncludeInspection */
        include_once TEMPLATEPATH . '/functions.php';
    }
}

/**
 * Fires after the theme is loaded.
 *
 * @since 3.0.0
 */
do_action('after_setup_theme');

// Set up current user.
$GLOBALS['wp']->init();

/**
 * Fires after WordPress has finished loading but before any headers are sent.
 *
 * Most of WP is loaded at this stage, and the user is authenticated. WP continues
 * to load on the {@see 'init'} hook that follows (e.g. widgets), and many plugins instantiate
 * themselves on it for all sorts of reasons (e.g. they need a user, a taxonomy, etc.).
 *
 * If you wish to plug an action once WP is loaded, use the {@see 'wp_loaded'} hook below.
 *
 * @since 1.5.0
 */
do_action('init');

/**
 * This hook is fired once WP, all plugins, and the theme are fully loaded and instantiated.
 *
 * Ajax requests should use wp-admin/admin-ajax.php. admin-ajax.php can handle requests for
 * users not logged in.
 *
 * @link https://codex.wordpress.org/AJAX_in_Plugins
 *
 * @since 3.0.0
 */
do_action( 'wp_loaded');