<?php
namespace AkTest\Wp\Test;

use Ak\Wp\ConfigProvider;
use Ak\Wp\Test\AbstractTestCase;
use Ak\Wp\Plugin\PluginInterface;

class WpTestTraitTest extends AbstractTestCase
{
    public $configProviders = [
        ConfigProvider::class,
    ];

    protected $installScripts = [
        __DIR__ . '/additional-install.php',
    ];

    protected $wpPlugins = [
        'woocommerce/woocommerce.php',
    ];

    public function testCanRunWordPress()
    {
        $html = $this->runWordPress();

        $this->assertNotEmpty($html);
        $this->assertSelectCount('html > body', 1, $html);
    }

    public function testWillUseRegularWordPressPlugins()
    {
        $this->assertEquals(1, did_action('woocommerce_loaded'));
    }

    public function testWillLoadPlugins()
    {
        $plugin = $this->createMock(PluginInterface::class);
        $plugin->expects($this->once())
            ->method('attach');

        $this->runWordPress($this->getContainer([
            'wp' => [
                'plugins' => [
                    'plugin',
                ],
            ],

            'wp_plugins' => [
                'services' => [
                    'plugin' => $plugin,
                ],
            ],
        ]));
    }

    public function testIsUsingFlatsome()
    {
        $html = $this->runWordPress();

        $this->assertContains('flatsome', $html);
    }

    public function testIsInCroatian()
    {
        $html = $this->runWordPress();

        $this->assertContains('<html lang="hr', $html);
        $this->assertContains('Samo još jedna', $html);
    }

    public function testPermalinksWork()
    {
        $html = $this->runWordPress();

        $this->assertContains('dan-svijete', $html);
    }

    public function testCanNavigate()
    {
        $_SERVER['REQUEST_URI'] .= '/dan-svijete';
        $html = $this->runWordPress();

        $this->assertTrue(is_single());
        $this->assertSelectCount('body.single.single-post', 1, $html);
    }

    public function testInstallScriptsAreRan()
    {
        $this->runWordPress();

        $this->assertEquals('installed', get_option('additional_install'));
    }
}
